#
# spec file for package caja
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname libcaja-extension1
%define typelib typelib-1_0-Caja-2_0
%define _version 1.16
Name:           caja
Version:        1.16.2
Release:        1.1
Summary:        File manager for the MATE desktop
License:        GPL-2.0 and LGPL-2.0
Group:          System/GUI/Other
Url:            http://mate-desktop.org/
Source:         http://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exempi-2.0)
BuildRequires:  pkgconfig(gail)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(unique-1.0)
Recommends:     %{name}-lang
# mate-file-manager was last used in openSUSE 13.1.
Provides:       mate-file-manager = %{version}
Obsoletes:      mate-file-manager < %{version}
Obsoletes:      mate-file-manager-lang < %{version}

%description
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

%lang_package

%package devel
Summary:        Caja development files
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
# mate-file-manager-devel was last used in openSUSE 13.1.
Provides:       mate-file-manager-devel = %{version}
Obsoletes:      mate-file-manager-devel < %{version}

%description devel
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

%package -n %{lname}
Summary:        Caja shared libraries
Group:          System/Libraries
Requires:       %{name}-gschemas = %{version}

%description -n %{lname}
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

# Needed for using pluma as standalone from MATE.

%package gschemas
Summary:        Caja GSchemas
Group:          System/Libraries
Obsoletes:      mate-file-manager < %{version}
# caja-gsettings-schemas was last used in openSUSE Leap 42.1.
Obsoletes:      %{name}-gsettings-schemas < %{version}
Provides:       %{name}-gsettings-schemas = %{version}
%glib2_gsettings_schema_requires

%description gschemas
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

This package provides the GSettings schemas for Caja.

%package -n %{typelib}
Summary:        MATE file manager typelib
Group:          System/GUI/Other

%description -n %{typelib}
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --libexecdir=%{_libexecdir}/%{name} \
  --disable-update-mimedb             \
  --disable-static                    \
  --with-gtk=2.0                      \
  --enable-introspection
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name}
find %{buildroot} -type f -name "*.la" -delete -print
# Create extensions directories.
mkdir -p %{buildroot}%{_libdir}/caja/extensions-2.0/ \
  %{buildroot}%{_datadir}/caja/extensions/ \
  %{buildroot}%{_datadir}/caja-extensions/

%suse_update_desktop_file caja-autorun-software
%suse_update_desktop_file caja-browser
%suse_update_desktop_file caja-computer
%suse_update_desktop_file caja-file-management-properties
%suse_update_desktop_file caja-folder-handler
%suse_update_desktop_file caja-home
%suse_update_desktop_file caja
%suse_update_desktop_file mate-network-scheme

%post
%desktop_database_post
%mime_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%mime_database_postun
%icon_theme_cache_postun

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%post gschemas
%glib2_gsettings_schema_post

%postun gschemas
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING.EXTENSIONS COPYING.LIB NEWS
%{_bindir}/caja
%{_bindir}/caja-autorun-software
%{_bindir}/caja-connect-server
%{_bindir}/caja-file-management-properties
%{_libexecdir}/caja/
%{_datadir}/caja/
%{_datadir}/dbus-1/services/org.mate.freedesktop.FileManager1.service
%{_datadir}/applications/caja-autorun-software.desktop
%{_datadir}/applications/caja-browser.desktop
%{_datadir}/applications/caja-computer.desktop
%{_datadir}/applications/caja-file-management-properties.desktop
%{_datadir}/applications/caja-folder-handler.desktop
%{_datadir}/applications/caja-home.desktop
%{_datadir}/applications/caja.desktop
%{_datadir}/applications/mate-network-scheme.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/*
%{_mandir}/man?/*.?%{?ext_man}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/caja.appdata.xml
# Own common extensions directories.
%dir %{_libdir}/caja/
%dir %{_libdir}/caja/extensions-2.0/
%dir %{_datadir}/caja/extensions/
%dir %{_datadir}/caja-extensions/

%files lang -f caja.lang
%defattr(-,root,root)

%files -n %{typelib}
%defattr(-,root,root)
%{_libdir}/girepository-1.0/Caja-2.0.typelib

%files -n %{lname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files gschemas
%defattr(-,root,root)
%{_datadir}/glib-2.0/schemas/*.xml

%files devel
%defattr(-,root,root)
%{_datadir}/gtk-doc/html/libcaja-extension/
%{_includedir}/caja/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libcaja-extension.pc
%{_datadir}/gir-1.0/Caja-2.0.gir

%changelog
* Sun Feb  5 2017 sor.alexei@meowr.ru
- Update to version 1.16.2:
  * List view: Show/hide columns instead of appending/removing them
    (fixes crash when moving between trash and other directory with
    GTK+3).
  * Icon view: Fix accessibility issues.
  * Icon and compact views: Fix moving to next/previous row (or
    column) with right/left (or down/up) keys.
  * Preferences dialogue: Fix vertical expand of content with
    window resize.
  * Show "Open with" menu item and "Open with" tab in properties
    window for .desktop and .theme files.
  * Fix cursor refresh issues on directory change in single click
    mode.
  * Fix runtime warnings on window closing and Caja exit.
  * GTK+3: Fix mousewheel scrolling in compact view.
  * GTK+3: Fix visual issues when renaming files.
  * GTK+3: Force the X11 backend.
  * Some more fixes and cleanups.
* Tue Oct 18 2016 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Fix a regression that sometimes caused visual glitches when
    selecting icons.
  * GTK+3: Some CSS adjustments.
  * GTK+3: Fix accessibility on desktop (for Orca).
  * GTK+3: Fix several runtime warnings.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Use GtkAboutDialog instead of MateAboutDialog.
  * Pathbar: Always show right arrow button.
  * Fix changing taskbar icon when switching between tabs with
    different icons.
  * Fix lots of warnings when building docs for libcaja-extension.
  * GTK+3: Add style classes for elements of pathbar.
  * GTK+3: Fix drawing and changing of desktop background with
    Gtk 3.21.
  * GTK+3: Fix a large amount of deprecations.
  * Some more fixes and cleanups.
  * Update translations.
* Wed Aug 10 2016 sor.alexei@meowr.ru
- Update to version 1.14.2:
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * prefs dialog: Don't crash on toggling "Show hidden and backup
    files".
  * GTK+-3 theming: Add a CSS file for caja, and initialise it at
    startup.
  * GTK+3: Add style class caja-desktop-window at top level.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Drop MateConf migration script.
  * Allow closing tabs on middle-click.
  * List Python extensions separately in extensions list.
  * GTK+3: Add several style classes to simplify theming.
  * GTK+3: Fix desktop flash issue.
  * GTK+3: A lot of deprecation fixes.
  * Some more fixes and cleanups.
  * Update translations.
  * Add Changelog generation.
* Tue Mar 29 2016 sor.alexei@meowr.ru
- Update to 1.12.7:
  * Fix remaining random changes of font color in icon view.
* Tue Mar 15 2016 sor.alexei@meowr.ru
- Update to 1.12.6:
  * Really fix loading multiple python extensions.
* Mon Mar 14 2016 sor.alexei@meowr.ru
- Update to 1.12.5:
  * Fix loading multiple Python extensions.
  * GTK+3: fix crash on Ctrl + scroll wheel.
- Rename caja-gsettings-schemas package to caja-gschemas.
* Thu Feb 18 2016 sor.alexei@meowr.ru
- Update to 1.12.4:
  * Fix random crash on startup when python-caja extension is
    enabled.
  * Fix crash when restoring file with special characters from
    trash.
  * Fix few memleaks.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to 1.12.3:
  * Fix wrong text colour in icon view with some light themes.
  * Fix crash due to unneeded assert.
* Wed Dec 23 2015 sor.alexei@meowr.ru
- Update 1.12.2:
  * Set smclient mode to "no restart" when either running as root
    or on other desktops.
  * Properties -> custom icon dialog: add missing /usr/share/icons/
    to Places.
  * Some other fixes.
* Sat Dec 12 2015 p.drouand@gmail.com
- Remove useless pkgconfig(pangox) requirement
* Sun Nov 29 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Assorted bugfixes.
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * GTK+3 fixes.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Connect to server dialog: add support for AFP.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Switch to org.gnome.SessionManager for logout/suspend inhibit.
  * Improve multi-monitor support.
  * Some UI fixes.
* Thu Sep 24 2015 sor.alexei@meowr.ru
- Update to 1.10.4:
  * Fix a crash when using undo following a file deletion.
* Tue Jul 21 2015 sor.alexei@meowr.ru
- Update to 1.10.3:
  * File properties dialog: bring back missing Notes and
    Image Properties tabs.
* Fri Jul 17 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Places sidebar: enable both creating bookmarks and dropping
    files.
  * Compact view: don't auto-scroll to the right on long filenames.
  * Don't manage desktop and exit with last window when either
    running as root or on other desktops.
  * Fix double-click behaviour when clicking on a folder and then
    on a file / directory inside it.
  * GTK+3 fixes.
  * Update translations update.
* Fri Jun 12 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Do not automount USB flash drives and CD/DVD drives while
    session is locked.
  * Revert dropping of files to Bookmarks sidebar.
  * UI bugfixes.
- Spec cleanup.
* Tue Apr 14 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * Bug fixes release
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bug fixes release
* Mon Mar 23 2015 p.drouand@gmail.com
- Own the new caja extensions directory
* Tue Jan 13 2015 p.drouand@gmail.com
- Update to version 1.9.4 (unstable)
  + Allow extensions to be enabled/disabled at runtime
  + Bugfixes
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.3 (unstable)
  + Allow extensions to be enabled/disabled at runtime
  + Bugfixes
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + bugfixes release
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.2
  + limit deep scount (folder contents and size) to one filesystem
  + Handle metadata key deletions
  + Propagate button-release event when ejecting
  + Fix text renderinf on no background
* Sat Apr 26 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + accessibility improvements
  + fixed x-caja-desktop issue
  + removed ConsoleKit usage
  + show trash icon in tree side panel
* Mon Mar 10 2014 p.drouand@gmail.com
- Add several obsoletes to avoid a lot of conflicts with
  mate-file-manager
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90
  + add GTK3 support
  + re add bookmark section in connect server dialog
  + add option to show file sizes with IEC units instead of SI units
  + add "Open parent location" in menu if we are in search view
* Mon Feb 10 2014 p.drouand@gmail.com
- Initial release (version 1.7.2)
